@@ -695,9 +695,7 @@ func TestSwiftIsAvailable(t *testing.T) {
 		Infrastructures: fakeInfrastructureLister(cloudName),
 		OpenShiftConfig: MockConfigMapNamespaceLister{},
 	}
-	res, err := IsSwiftEnabled(listers)
-	th.AssertNoErr(t, err)
-	th.AssertEquals(t, true, res)
+	th.AssertEquals(t, true, IsSwiftEnabled(listers))
 }
 
 func TestSwiftIsNotAvailable(t *testing.T) {
@@ -749,9 +747,7 @@ func TestSwiftIsNotAvailable(t *testing.T) {
 		Infrastructures: fakeInfrastructureLister(cloudName),
 		OpenShiftConfig: MockConfigMapNamespaceLister{},
 	}
-	res, err := IsSwiftEnabled(listers)
-	th.AssertNoErr(t, err)
-	th.AssertEquals(t, false, res)
+	th.AssertEquals(t, false, IsSwiftEnabled(listers))
 }
 
 func TestNoPermissionsKeystone(t *testing.T) {
@@ -801,9 +797,7 @@ func TestNoPermissionsKeystone(t *testing.T) {
 		Infrastructures: fakeInfrastructureLister(cloudName),
 		OpenShiftConfig: MockConfigMapNamespaceLister{},
 	}
-	res, err := IsSwiftEnabled(listers)
-	th.AssertNoErr(t, err)
-	th.AssertEquals(t, false, res)
+	th.AssertEquals(t, false, IsSwiftEnabled(listers))
 }
 
 func TestNoPermissionsSwauth(t *testing.T) {
@@ -853,7 +847,5 @@ func TestNoPermissionsSwauth(t *testing.T) {
 		Infrastructures: fakeInfrastructureLister(cloudName),
 		OpenShiftConfig: MockConfigMapNamespaceLister{},
 	}
-	res, err := IsSwiftEnabled(listers)
-	th.AssertNoErr(t, err)
-	th.AssertEquals(t, false, res)
+	th.AssertEquals(t, false, IsSwiftEnabled(listers))
 }
